# 0.1.5
    Fixing bug in audio alignment with time stretching

# 0.1.3
    - Adding MANIFEST.in file so that all of the source files are included when building from source

# 0.1.2
    - Adding README and finalizing structure for docs
